==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QPageRanges_Range_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpageranges.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPageRanges_Range(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPageRanges::Range")
    QPageRanges::Range *_ptr = reinterpret_cast<QPageRanges::Range *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QPageRanges_Range_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QPageRanges::Range *__qt_this = new(__qtjambi_ptr) QPageRanges::Range();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPageRanges::Range
void __qt_destruct_QPageRanges_Range(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPageRanges::Range")
    reinterpret_cast<QPageRanges::Range*>(ptr)->~Range();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPageRanges::Range::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_initialize_1native__Lio_qt_gui_QPageRanges_00024Range_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPageRanges::Range::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPageRanges_Range_0, sizeof(QPageRanges::Range), typeid(QPageRanges::Range), false, &deleter_QPageRanges_Range, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPageRanges::Range::contains(int)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_contains_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint pageNumber0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPageRanges::Range::contains(int)const", __qt_this)
        __java_return_value = __qt_this->contains(static_cast<int>(pageNumber0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPageRanges::Range::operator<(QPageRanges::Range,QPageRanges::Range)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_operator_1less_1native_1QPageRanges_1Range__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPageRanges::Range::operator<(QPageRanges::Range,QPageRanges::Range)", __qt_this)
        QPageRanges::Range __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QPageRanges::Range>(rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPageRanges::Range::operator==(QPageRanges::Range,QPageRanges::Range)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_equals_1native_1QPageRanges_1Range__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPageRanges::Range::operator==(QPageRanges::Range,QPageRanges::Range)", __qt_this)
        QPageRanges::Range __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QPageRanges::Range>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_setFrom_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint from0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->from = static_cast<int>(from0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_from_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->from;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_setTo_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint to0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->to = static_cast<int>(to0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_to_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->to;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPageRanges_Range(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPageRanges::Range>("QPageRanges::Range", "io/qt/gui/QPageRanges$Range");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPageRanges_Range, {
        ConstructorInfo(&__qt_construct_QPageRanges_Range_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPageRanges_Range);
    registerMetaType<QPageRanges::Range>("QPageRanges::Range");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QPageRanges_Range_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpageranges.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPageRanges_Range(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPageRanges::Range")
    QPageRanges::Range *_ptr = reinterpret_cast<QPageRanges::Range *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Range()
void __qt_construct_QPageRanges_Range(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Range()")
    Q_UNUSED(__java_arguments)
    QPageRanges::Range *__qt_this = new(__qtjambi_ptr) QPageRanges::Range();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPageRanges::Range::Range()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_initialize_1native__Lio_qt_gui_QPageRanges_00024Range_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPageRanges::Range::Range()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPageRanges_Range, sizeof(QPageRanges::Range), typeid(QPageRanges::Range), false, &deleter_QPageRanges_Range, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Range(QPageRanges::Range)
void __qt_construct_QPageRanges_Range_cref_QPageRanges_Range(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Range(QPageRanges::Range)")
    jobject other0 = __java_arguments[0].l;
    const QPageRanges::Range& __qt_other0 = qtjambi_cast<const QPageRanges::Range& >(__jni_env, other0);
    QPageRanges::Range *__qt_this = new(__qtjambi_ptr) QPageRanges::Range(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPageRanges::Range::Range(QPageRanges::Range)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_initialize_1native__Lio_qt_gui_QPageRanges_00024Range_2Lio_qt_gui_QPageRanges_00024Range_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPageRanges::Range::Range(QPageRanges::Range)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPageRanges_Range_cref_QPageRanges_Range, sizeof(QPageRanges::Range), typeid(QPageRanges::Range), false, &deleter_QPageRanges_Range, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Range{int,int}
void __qt_construct_QPageRanges_Range_int_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Range{int,int}")
    jint from0 = __java_arguments[0].i;
    Q_UNUSED(from0)
    jint to1 = __java_arguments[1].i;
    Q_UNUSED(to1)
    QPageRanges::Range *__qt_this = new(__qtjambi_ptr) QPageRanges::Range{static_cast<int>(from0), static_cast<int>(to1)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPageRanges::Range::Range{int,int}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_initialize_1native__Lio_qt_gui_QPageRanges_00024Range_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint from0,
 jint to1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPageRanges::Range::Range{int,int}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].i = from0;
        arguments[1].i = to1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPageRanges_Range_int_int, sizeof(QPageRanges::Range), typeid(QPageRanges::Range), false, &deleter_QPageRanges_Range, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPageRanges::Range
void __qt_destruct_QPageRanges_Range(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPageRanges::Range")
    reinterpret_cast<QPageRanges::Range*>(ptr)->~Range();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPageRanges::Range::contains(int)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_contains_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint pageNumber0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPageRanges::Range::contains(int)const", __qt_this)
        __java_return_value = __qt_this->contains(static_cast<int>(pageNumber0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPageRanges::Range::operator<(QPageRanges::Range,QPageRanges::Range)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_operator_1less_1native_1QPageRanges_1Range__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPageRanges::Range::operator<(QPageRanges::Range,QPageRanges::Range)", __qt_this)
        QPageRanges::Range __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QPageRanges::Range>(rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPageRanges::Range::operator==(QPageRanges::Range,QPageRanges::Range)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_equals_1native_1QPageRanges_1Range__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPageRanges::Range::operator==(QPageRanges::Range,QPageRanges::Range)", __qt_this)
        QPageRanges::Range __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QPageRanges::Range>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_setFrom_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint from0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->from = static_cast<int>(from0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_from_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->from;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_setTo_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint to0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->to = static_cast<int>(to0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_to_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->to;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPageRanges_00024Range_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPageRanges::Range *__qt_this = QtJambiAPI::objectFromNativeId<QPageRanges::Range>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPageRanges_Range(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPageRanges::Range>("QPageRanges::Range", "io/qt/gui/QPageRanges$Range");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPageRanges_Range, {
        ConstructorInfo(&__qt_construct_QPageRanges_Range, nullptr)
       ,ConstructorInfo(&__qt_construct_QPageRanges_Range_cref_QPageRanges_Range, "Lio/qt/gui/QPageRanges$Range;")
       ,ConstructorInfo(&__qt_construct_QPageRanges_Range_int_int, "II")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPageRanges_Range);
    registerMetaType<QPageRanges::Range>("QPageRanges::Range");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
